@@ -16,7 +16,7 @@ import inspect
 import pyagentx2
 from pyagentx2.updater import Updater
 from pyagentx2.network import Network
-from pyagentx2.mib import MIB
+from pyagentx2.mib import MIB, MIB_SQLite, MIB_MySQL
 
 
 
@@ -25,12 +25,20 @@ class AgentError(Exception):
 
 class Agent(object):
 
-    def __init__(self):
+    def __init__(self, mib_type='ram', mariadb_host='localhost', mariadb_user='rmon', mariadb_pass='rmon', database='rmon', table='mib', sync_freq=10, auto_sync=None):
         self._oid_list = []
         self._updater_list = []
         self._sethandlers = {}
         self._threads = []
-        self.mib = MIB()
+        if mib_type == 'ram':
+            self.mib = MIB()
+        elif (mib_type == 'sqlite') :
+            self.mib = MIB_SQLite(database, table, sync_freq, auto_sync)
+        elif (mib_type == 'mysql'):
+            self.mib = MIB_MySQL(mariadb_host, mariadb_user, mariadb_pass, database, table, sync_freq, auto_sync)
+        else:
+            logger.error("Unsupported mib type " + mib_type + ". Falling back to ram mib")
+            self.mib = MIB()
 
     def register(self, oid):
         # cleanup and test oid
